@@ -4,6 +4,7 @@ from pathlib import Path
 import shutil
 import numpy
 import multiprocessing as mp
+import gc
 
 
 def move_files(source_dir, chunk, dest_dir, chunk_name):
@@ -58,8 +59,10 @@ def chunk_files(raw_dataset, dest_dir: str,
                         raise
                     finally:
                         pool.close()
+                        gc.collect()
         else:
             move_files(all_documents_flatten_dir, chunk, dest_dir, chunk_name)
+            gc.collect()
 
         end = time.time() - start
         print("Time move chunk " + str(index) + " " + str(end))
