@@ -50,8 +50,8 @@ dir_list = [p for p in Path(output_jsons).iterdir() if p.is_dir()]
 
 for dir_path in dir_list:
     dir_name = dir_path.name
-    source = str(data_output_dir_path / dir_name)
-    dummy_path = str(data_output_dir_path / dir_name / 'dummy.json')
+    source = str(output_jsons / dir_name)
+    dummy_path = str(output_jsons / dir_name / 'dummy.json')
 
     subdir_list = [p for p in Path(source).iterdir() if p.is_dir()]
     subfiles_list = [p for p in Path(source).iterdir() if p.is_file()]
